% ----------------------
% TE.m
% ----------------------
% computes the temporary equilibrium for the global time 't'
% in:   -
% out:  edy
% ----------------------

function edyresid = TE()

global t rho sigma gam psi
global Y Div w I J V K H Omega C TB DF A edy r
global A_0 alpha L ell0 N NB delta

% DEMOGRAPHY
N(t+1)  = gam(t+1)*N(t)+NB(t+1);
L(t)    = ell0*N(t);

% PRODUCTION
Y(t)    = A_0*K(t)^alpha*L(t)^(1-alpha);
w(t)    = (1-alpha)*Y(t)/L(t);

% INVESTMENT
a1      = psi/K(t);
a2      = (1-delta*psi)+(1-delta)*psi;
a3      = (1-delta)*(1-delta*psi)*K(t)-V(t+1)/(1+r(t+1));
I(t)    = (-a2+sqrt(a2^2-4*a1*a3))/(2*a1);
J(t)    = 1/2*psi*K(t)*(I(t)/K(t)-delta)^2;
K(t+1)  = I(t)+(1-delta)*K(t);

% FIRM VALUE
Div(t)  = Y(t)-w(t)*L(t)-I(t)-J(t);
V(t)    = Div(t)+V(t+1)/(1+r(t+1));

% CONSUMPTION AND SAVINGS
Omega(t)= 1+(1/(1+rho))^sigma*(1+r(t+1))^(sigma-1)*gam(t+1)*Omega(t+1);
H(t)    = w(t)*L(t)+gam(t+1)*H(t+1)*(N(t)/N(t+1))/(1+r(t+1));
A(t)    = DF(t)+V(t);
C(t)    = (H(t)+A(t))/Omega(t);

TB(t)   = Y(t)-C(t)-I(t)-J(t);
DF(t+1) = (1+r(t+1))*(DF(t)+TB(t));

% EQUILIBRIUM
edy(t)  = I(t)+J(t)+C(t)+TB(t)-Y(t);
edyresid = edy(t);

end

