% ----------------------
% findcalib.m
% ----------------------
% computes calibration
% in:   foreignassets
% out:  resid
% ----------------------

function resid = findcalib(foreignassets)

    global gam0 rho sigma r0 psi delta ell0 w0 N0 Y0 
    global A_0 alpha H0 A0 K0 L0 I0 J0 Div0 V0 Omega0 C0 TB0
    
    DF0     = foreignassets;
    
    Omega0  = 1/(1-(1/(1+rho))^sigma*(1+r0)^(sigma-1)*gam0);
    L0      = ell0*N0;
    K0      = (Y0-w0*L0)/(r0+delta);
    I0      = delta*K0;
    J0      = 1/2*psi*K0*(I0/K0-delta)^2;
    alpha   = (r0+delta)*K0/Y0;
    A_0     = Y0/(K0^alpha*L0^(1-alpha));
    Div0    = Y0-w0*L0-I0-J0;
    V0      = (1+r0)*Div0/r0;
    H0      = (1+r0)*w0*L0/(r0+1-gam0);
    A0      = DF0+V0;
    C0      = (A0+H0)/Omega0;
    TB0     = Y0-C0-I0-J0;
    resid   = DF0+(1+r0)/r0*TB0;
end